@@ -88,7 +88,8 @@ Compositor::Compositor(QObject* workspace)
     , m_finishing(false)
     , m_timeSinceLastVBlank(0)
     , m_scene(NULL)
-    , m_waitingForFrameRendered(false)
+    , m_bufferSwapPending(false)
+    , m_composeAtSwapCompletion(false)
 {
     qRegisterMetaType<Compositor::SuspendReason>("Compositor::SuspendReason");
     connect(&unredirectTimer, SIGNAL(timeout()), SLOT(delayedCheckUnredirect()));
@@ -113,14 +114,16 @@ Compositor::Compositor(QObject* workspace)
     if (kwinApp()->operationMode() != Application::OperationModeX11) {
         connect(Wayland::WaylandBackend::self(), &Wayland::WaylandBackend::systemCompositorDied, this, &Compositor::finish);
         connect(Wayland::WaylandBackend::self(), &Wayland::WaylandBackend::backendReady, this, &Compositor::setup);
-    }
+    } else
 #endif
 
+    {
     // delay the call to setup by one event cycle
     // The ctor of this class is invoked from the Workspace ctor, that means before
     // Workspace is completely constructed, so calling Workspace::self() would result
     // in undefined behavior. This is fixed by using a delayed invocation.
     QMetaObject::invokeMethod(this, "setup", Qt::QueuedConnection);
+    }
 
     // register DBus
     new CompositorDBusInterface(this);
@@ -557,22 +560,35 @@ void Compositor::timerEvent(QTimerEvent *te)
         QObject::timerEvent(te);
 }
 
-void Compositor::lastFrameRendered()
+void Compositor::aboutToSwapBuffers()
 {
-    if (!m_waitingForFrameRendered) {
-        return;
+    assert(!m_bufferSwapPending);
+
+    m_bufferSwapPending = true;
+}
+
+void Compositor::bufferSwapComplete()
+{
+    assert(m_bufferSwapPending);
+    m_bufferSwapPending = false;
+
+    if (m_composeAtSwapCompletion) {
+        m_composeAtSwapCompletion = false;
+        performCompositing();
     }
-    m_waitingForFrameRendered = false;
-    performCompositing();
 }
 
 void Compositor::performCompositing()
 {
     if (m_scene->usesOverlayWindow() && !isOverlayWindowVisible())
         return; // nothing is visible anyway
-    if (!m_scene->isLastFrameRendered()) {
-        m_waitingForFrameRendered = true;
-        return; // frame wouldn't make it on the screen
+
+    // If a buffer swap is still pending, we return to the event loop and
+    // continue processing events until the swap has completed.
+    if (m_bufferSwapPending) {
+        m_composeAtSwapCompletion = true;
+        compositeTimer.stop();
+        return;
     }
 
     // Create a list of all windows in the stacking order
@@ -586,8 +602,10 @@ void Compositor::performCompositing()
             damaged << win;
     }
 
-    if (damaged.count() > 0)
+    if (damaged.count() > 0) {
+        m_scene->triggerFence();
         xcb_flush(connection());
+    }
 
     // Move elevated windows to the top of the stacking order
     foreach (EffectWindow *c, static_cast<EffectsHandlerImpl *>(effects)->elevatedWindows()) {
@@ -671,6 +689,10 @@ void Compositor::setCompositeTimer()
     if (!hasScene())  // should not really happen, but there may be e.g. some damage events still pending
         return;
 
+    // Don't start the timer if we're waiting for a swap event
+    if (m_bufferSwapPending && m_composeAtSwapCompletion)
+        return;
+
     uint waitTime = 1;
 
     if (m_scene->blocksForRetrace()) {
